@@ -24,7 +24,7 @@ class Eos:
         """
 		node CreateAccount.js 'http://172.18.0.1:8888' 'eosio' 'mytest12' '5KQwrPbwdL6PhXujxW37FSSQZ1JiwsST4cqQzDeyXtP79zkvFD3' '5JuaVWh3LDh1VH69urCdCa3A2YiQydbsLM1ZtGgsTXLYouxaTfc' 'EOS7vTHtMbZ1g9P8BiyAGD7Ni7H6UALVLVCW13xZrXT4heCBke3it' 'EOS8KKKYBBdwrmXRRynDXSxTX2qoT9TA4agahXXF4ccUgRCy81RNc' 8192 '100.0000 SYS' '100.0000 SYS' 0
 		"""
-        arguments = '"%s" "%s" "%s" "%s" "%s" "%s" %s "%s" "%s" %s' % (
+        arguments = "'%s' '%s' '%s' '%s' '%s' '%s' '%s' '%s' '%s' %s" % (
             self.http_address,
             config['creator'] if 'creator' in config else 'eosio',
             config['name'],
@@ -47,7 +47,7 @@ class Eos:
         """
 		node PushContractTransaction.js 'http://127.0.0.1:8888' '5JhhMGNPsuU52XXjZ57FcDKvbb7KLrEhN65tdTQFrH51uruZLHi' 'eosio.token' 'transfer' 'eva' 'active' '{"from":"eva","to":"rider1","quantity":"1 EVA","memo":""}'
 		"""
-        arguments = '"%s" "%s" "%s" "%s" "%s" "%s" "%s" ' % (
+        arguments = "'%s' '%s' '%s' '%s' '%s' '%s' '%s' " % (
             self.http_address,
             self.key_provider,
             acct_contract,
@@ -85,7 +85,7 @@ class Eos:
         """
 		node GetCurrencyBalance.js 'http://127.0.0.1:8888' '5JhhMGNPsuU52XXjZ57FcDKvbb7KLrEhN65tdTQFrH51uruZLHi' 'eosio.token' 'xd455yhesww2' 'EVA'
 		"""
-        arguments = '"%s" "%s" "%s" "%s" "%s" ' % (
+        arguments = "'%s' '%s' '%s' '%s' '%s' " % (
             self.http_address,
             self.key_provider,
             code,
